@@ -21,14 +21,14 @@ __docformat__ = "restructuredtext en"
 # pylint: disable-msg=W0622
 
 # package name
-modname = 'yams'
+modname = "yams"
 
 # release version
-numversion = (0, 45, 5)
-version = '.'.join(str(num) for num in numversion)
+numversion = (0, 47, 0)
+version = ".".join(str(num) for num in numversion)
 
 # license and copyright
-license = 'LGPL'
+license = "LGPL"
 
 # short and long description
 description = "entity / relation schema"
@@ -41,20 +41,19 @@ author_email = "devel@logilab.fr"
 web = "https://www.logilab.org/project/%s" % modname
 
 # mailing list
-mailinglist = 'mailto://python-projects@lists.logilab.org'
+mailinglist = "mailto://python-projects@lists.logilab.org"
 
 # executable
-scripts = ['bin/yams-check', 'bin/yams-view']
+scripts = ["bin/yams-check", "bin/yams-view"]
 
 install_requires = [
-    'setuptools',
-    'logilab-common >= 1.4.0',
-    'logilab-database >= 1.11',
-    'six >= 1.4.0',
-    ]
+    "setuptools",
+    "logilab-common >= 1.6.0",
+    "logilab-database >= 1.11",
+]
 
 classifiers = [
     "Programming Language :: Python",
-    "Programming Language :: Python :: 2",
     "Programming Language :: Python :: 3",
-    ]
+    "Programming Language :: Python :: 3 :: Only",
+]
