@@ -25,11 +25,11 @@ from logilab.common.testlib import TestCase, unittest_main
 from yams.reader import SchemaLoader
 from yams import schema2dot
 
-DATADIR = osp.abspath(osp.join(osp.dirname(__file__), 'data'))
+DATADIR = osp.abspath(osp.join(osp.dirname(__file__), "data"))
 
 schema = SchemaLoader().load([DATADIR])
 
-DOT_SOURCE = r'''digraph "toto" {
+DOT_SOURCE = r"""digraph "toto" {
 rankdir=BT
 ratio=compress
 charset="utf-8"
@@ -43,19 +43,19 @@ splines=true
 "Person" -> "Societe" [arrowhead="normal", arrowtail="none", color="#aa0000", decorate="false", fontcolor="#aa0000", headlabel="0..n", label="travaille", style="filled", taillabel="0..n"];
 "Salaried" -> "Societe" [arrowhead="normal", arrowtail="none", color="#00aa00", decorate="false", fontcolor="#00aa00", headlabel="0..n", label="travaille", style="filled", taillabel="0..n"];
 }
-'''
+"""  # noqa
+
 
 class DotTC(TestCase):
-
     def test_schema2dot(self):
         """tests dot conversion without attributes information"""
-        wanted_entities = set(('Person', 'Salaried', 'Societe'))
-        skipped_entities = set(ent for ent in schema.entities()
-                               if ent.type not in wanted_entities)
-        schema2dot.schema2dot(schema, 'toto.dot', skiptypes=skipped_entities)
-        generated = open('toto.dot').read()
-        os.remove('toto.dot')
+        wanted_entities = {"Person", "Salaried", "Societe"}
+        skipped_entities = {ent for ent in schema.entities() if ent.type not in wanted_entities}
+        schema2dot.schema2dot(schema, "toto.dot", skiptypes=skipped_entities)
+        generated = open("toto.dot").read()
+        os.remove("toto.dot")
         self.assertMultiLineEqual(DOT_SOURCE, generated)
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     unittest_main()
